import { useEffect, useRef, useState } from "react";
import WebViewer, { Annotations } from "@pdftron/webviewer";

import {
  Button,
  Dialog,
  DialogContent,
  DialogTitle,
  FormControl,
  Grid,
  TextField,
  DialogActions,
} from "@material-ui/core";
import CloseIcon from "@mui/icons-material/Close";
import DoneIcon from "@mui/icons-material/Done";

const App = () => {
  const viewer = useRef(null);
  const urlInput = useRef();
  const [openDialog, setOpenDialog] = useState(false);
  const [value, setValue] = useState();
  const [instance, setInstance] = useState(null);
  // const [page, setPage] = useState(1);
  const [cords, setCords] = useState({
    pageNumber: 1,
    x: 0,
    y: 0,
  });
  const handleFlagClose = () => {
    setOpenDialog(false);
  };

  const [url, setURL] = useState("");

  useEffect(() => {
    WebViewer(
      {
        path: "lib",
        initialDoc:
          "https://pdftron.s3.amazonaws.com/downloads/pl/webviewer-demo.pdf",
      },
      viewer.current
    ).then((instance) => {
      // const { documentViewer } = instance.Core;
      // you can now call WebViewer APIs here...
      setInstance(instance);

      const { docViewer } = instance;

      instance.textPopup.update([
        {
          type: "actionButton",
          title: "tool.Link",
          img: "icon-tool-link",
          onClick: (arg) => {
            console.log(arg);
            console.log(instance.docViewer.getSelectedText());
            console.log(instance.docViewer)
            setOpenDialog(true);
            setCords(instance.docViewer.qI.AnnotationEdit.pageCoordinates[1])
          },
        },
      ]);

      // docViewer.on("pageNumberUpdated", (pageNumber) => {
      //   setPage(pageNumber);
      // });

      // instance.textPopup.update([
      //   {
      //     type: "actionButton",
      //     img: "https://www.pdftron.com/favicon-32x32.png",
      //     onClick: (value) => {
      //       setOpenDialog(true);
      //     },
      //   },
      // ]);
    });
  }, []);

  const handleSubmit = (e) => {
    e.preventDefault();

    const { Actions, Annotations, annotManager, docViewer } = instance;
    // console.log(docViewer.getWidth())
    docViewer.getPageWidth(1);
    docViewer.getPageHeight(1);

    const newLink = new Annotations.Link();

    Object.assign(newLink, {
      ...cords,
      Height: docViewer.getPageHeight(cords.pageNumber),
      Width: docViewer.getPageWidth(cords.pageNumber),
    });

    newLink.StrokeColor = new Annotations.Color(0, 165, 228);
    newLink.StrokeStyle = "underline";
    newLink.StrokeThickness = 2;

    newLink.addAction(
      docViewer.getSelectedText(),
      new Actions.URI({
        uri: url,
      })
    );

    annotManager.addAnnotation(newLink);
    console.log(newLink);
  };

  return (
    <div className="App">
      <div className="webviewer" ref={viewer} style={{ height: "100vh" }}>
        <Dialog
          open={openDialog}
          onClose={handleFlagClose}
          aria-labelledby="draggable-dialog-title"
          aria-describedby="alert-dialog-description"
          style={{ minWidth: "500px" }}
        >
          <DialogTitle>ADD URL</DialogTitle>

          <DialogContent>
            <Grid style={{ display: "grid", gridTemplateColumns: "20rem 1fr" }}>
              <Grid>
                <TextField
                  InputLabelProps={{ shrink: false }}
                  variant="outlined"
                  id="outlined-text"
                  type="Text"
                  value={url}
                  onChange={(e) => console.log(setURL(e.target.value))}
                  ref={urlInput}
                  size="small"
                  fullWidth
                />
              </Grid>
            </Grid>
          </DialogContent>
          <DialogActions>
            <Button
              color="primary"
              variant="outlined"
              endIcon={<CloseIcon />}
              onClick={handleFlagClose}
            >
              Close
            </Button>
            <form onSubmit={handleSubmit}>
              <div className="linkInput">
                <Button
                  variant="outlined"
                  endIcon={<DoneIcon />}
                  color="primary"
                  type="submit"
                >
                  Submit
                </Button>
              </div>
            </form>
          </DialogActions>
        </Dialog>
      </div>
    </div>
  );
};

export default App;
